// Titlebar Tweaks extension for Mozilla Firefox
// Copyright (C) 2004-2007  Michael O'Rourke / Cosmic Cat Creations (http://www.cosmicat.com/)
// For licensing terms, please refer to readme.txt in this extension's XPInstall 
// package or its installation directory on your computer.

var TitleTweak = {
	init: function() {
		this.Prefs = new TitleTweak_PrefManager();
		this.setCustomName();
		this.setTitleMode();
		this.Prefs.addPrefObserver("TitleTweak.prefObserver");
	},
	init2: function() {
		document.getElementById("content")
				.addEventListener("DOMTitleChanged", TitleTweak.updateTitlebar, false);  // footnote "DOMTitle"
	},
	destruct: function() {
		try { this.Prefs.removePrefObserver(); } catch(ex) {}
	},
	getPref: function(strName) {
		return this.Prefs.getPref(strName);
	},
	prefObserver: function(subject, topic, prefName) {
		switch (prefName) {
			case "extensions.titletweak.customname": this.setCustomName(); break;
			case "extensions.titletweak.mode": this.setTitleMode(); break;
		}
	},
	setCustomName: function() {
		this.customName = this.getPref("extensions.titletweak.customname");
		setTimeout("TitleTweak.updateTitlebar();", 50);
	},
	setTitleMode: function() {
		var tabbrowser = document.getElementById("content");
		switch(this.getPref("extensions.titletweak.mode")) {
			case 1: tabbrowser.updateTitlebar = TitleTweak.titleMode1; break;
			case 2: tabbrowser.updateTitlebar = TitleTweak.titleMode2; break;
			case 3: tabbrowser.updateTitlebar = TitleTweak.titleMode3; break;
			case 4: tabbrowser.updateTitlebar = TitleTweak.titleMode4; break;
		}
		setTimeout("TitleTweak.updateTitlebar();", 50);
	},
	updateTitlebar: function() {
		try { document.getElementById("content").updateTitlebar(); } catch(ex) {}
	},
	titleMode1: function() {
		/* display document title, then titlemodifier */
		var newTitle = "";
		var docTitle;
		if (this.docShell.contentViewer) { docTitle = this.contentDocument.title; }
		if (!docTitle) { docTitle = this.ownerDocument.documentElement.getAttribute("titledefault"); }
		var modifier = this.ownerDocument.documentElement.getAttribute("titlemodifier");
		if (TitleTweak.customName) { modifier = TitleTweak.customName; }
		if (docTitle) {
			newTitle += this.ownerDocument.documentElement.getAttribute("titlepreface");
			newTitle += docTitle;
			var sep = this.ownerDocument.documentElement.getAttribute("titlemenuseparator");
			if (modifier) { newTitle += sep; }
		}
		newTitle += modifier;
		this.ownerDocument.title = newTitle;
	},
	titleMode2: function() {
		/* display only the document title */
		var docTitle;
		if (this.docShell.contentViewer) { docTitle = this.contentDocument.title; }
		if (!docTitle) { docTitle = this.ownerDocument.documentElement.getAttribute("titledefault"); }
		this.ownerDocument.title = docTitle;
	},
	titleMode3: function() {
		/* display titlemodifier, then document title */
		var newTitle = "";
		var docTitle;
		if (this.docShell.contentViewer) { docTitle = this.contentDocument.title; }
		if (!docTitle) { docTitle = this.ownerDocument.documentElement.getAttribute("titledefault"); }
		var modifier = this.ownerDocument.documentElement.getAttribute("titlemodifier");
		if (TitleTweak.customName) { modifier = TitleTweak.customName; }
		newTitle += modifier;
		if (docTitle) {
			var sep = this.ownerDocument.documentElement.getAttribute("titlemenuseparator");
			if (modifier) { newTitle += sep; }
			newTitle += this.ownerDocument.documentElement.getAttribute("titlepreface");
			newTitle += docTitle;
		}
		this.ownerDocument.title = newTitle;
	},
	titleMode4: function() {
		/* display only the titlemodifier */
		var modifier = this.ownerDocument.documentElement.getAttribute("titlemodifier");
		if (TitleTweak.customName) { modifier = TitleTweak.customName; }
		this.ownerDocument.title = modifier;
	}
}

TitleTweak.init();
window.addEventListener("load", function() { TitleTweak.init2(); }, false);
window.addEventListener("unload", function() { TitleTweak.destruct(); }, false);



/* *** FOOTNOTES ***

DOMTitle: In some cases, tabbrowser::updateTitlebar() will not use the replaced method 
the first time it is loaded. Forcing an update with the "DOMTitleChanged" event seems 
to remedy this behavior with minimal overhead.
	
*/
